Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(139)

Unified Diff: tools/persistent_process_info.sh

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/lk/run_snapshot_lk_qemu.sh ('k') | tools/promote.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/persistent_process_info.sh
diff --git a/tools/persistent_process_info.sh b/tools/persistent_process_info.sh
index 107620d5eb1a1065e49dc8747dc05e73bcbf3206..97e4e0e96e4f2b16783b617ce2a65e562aa658c1 100755
--- a/tools/persistent_process_info.sh
+++ b/tools/persistent_process_info.sh
@@ -3,22 +3,22 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE.md file.
# This program displays information about the Fletch persistent process.
#
# It supports an option -k (or --kill) which will kill the process after
# displaying the information.
#
# This is a tool that's intended for people building the Fletch VM. If you find
# yourself using this on a regular basis, please get in touch with the authors
# and let us know why. If you're unsure about how to reach the authors, you're
# welcome to file an issue at https://github.com/dart-lang/fletch/issues/new.
# Using ~ instead of $HOME as this should match what the fletch command does
# (it will fall back to getpwuid_r if HOME isn't defined).
-fletch_file=~/.fletch
+dartino_file=~/.dartino
-if [ -f "$FLETCH_SOCKET_FILE" ]; then
- fletch_file="$FLETCH_SOCKET_FILE"
+if [ -f "$DARTINO_SOCKET_FILE" ]; then
+ dartino_file="$DARTINO_SOCKET_FILE"
fi
for argument in "$@"; do
@@ -31,7 +31,7 @@ for argument in "$@"; do
has_bad_options=1
;;
*)
- fletch_file="$argument"
+ dartino_file="$argument"
;;
esac
done
@@ -40,14 +40,14 @@ if [ $has_bad_options ]; then
exit 1
fi
-for socket in $(xargs < $fletch_file) ; do
+for socket in $(xargs < $dartino_file) ; do
if [ -e "$socket" ] ; then
for pid in $(lsof -t -- "$socket" ) ; do
- echo Persistent Fletch process $pid:
+ echo Persistent Dartino process $pid:
ps -w -w -o args= -p $pid
if [ $kill ]; then
kill -TERM $pid
- : > $fletch_file
+ : > $dartino_file
fi
done
fi
@@ -3,22 +3,22 @@
# for details. All rights reserved. Use of this source code is governed by a
# BSD-style license that can be found in the LICENSE.md file.
-# This program displays information about the Fletch persistent process.
+# This program displays information about the Dartino persistent process.
#
# It supports an option -k (or --kill) which will kill the process after
@@ -3,22 +3,22 @@
# displaying the information.
#
-# This is a tool that's intended for people building the Fletch VM. If you find
+# This is a tool that's intended for people building the Dartino VM. If you find
# yourself using this on a regular basis, please get in touch with the authors
# and let us know why. If you're unsure about how to reach the authors, you're
@@ -3,22 +3,22 @@
# yourself using this on a regular basis, please get in touch with the authors
# and let us know why. If you're unsure about how to reach the authors, you're
-# welcome to file an issue at https://github.com/dart-lang/fletch/issues/new.
+# welcome to file an issue at https://github.com/dart-lang/dartino/issues/new.
-# Using ~ instead of $HOME as this should match what the fletch command does
+# Using ~ instead of $HOME as this should match what the dartino command does
# (it will fall back to getpwuid_r if HOME isn't defined).
« no previous file with comments | « tools/lk/run_snapshot_lk_qemu.sh ('k') | tools/promote.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698